@@ -95,6 +95,9 @@ namespace awkward {
     const std::vector<std::string>
       keys() const override;
 
+    bool
+      istuple() const override;
+
     bool
       equal(const FormPtr& other,
             bool check_identities,
@@ -416,6 +419,9 @@ namespace awkward {
     const std::vector<std::string>
       keys() const override;
 
+    bool
+      istuple() const override;
+
     // operations
     const std::string
       validityerror(const std::string& path) const override;
@@ -471,24 +477,19 @@ namespace awkward {
                 const Index64& parents,
                 int64_t outlength,
                 bool ascending,
-                bool stable,
-                bool keepdims) const override;
+                bool stable) const override;
 
-    const ContentPtr
-      sort_asstrings(const Index64& offsets,
-                     bool ascending,
-                     bool stable) const;
     const ContentPtr
       as_unique_strings(const Index64& offsets) const;
 
     const ContentPtr
       argsort_next(int64_t negaxis,
                    const Index64& starts,
+                   const Index64& shifts,
                    const Index64& parents,
                    int64_t outlength,
                    bool ascending,
-                   bool stable,
-                   bool keepdims) const override;
+                   bool stable) const override;
 
     const ContentPtr
       localindex(int64_t axis, int64_t depth) const override;
@@ -574,14 +575,6 @@ namespace awkward {
                    const Slice& tail,
                    const Index64& advanced) const override;
 
-    const ContentPtr
-      getitem_next(const SliceVarNewAxis& varnewaxis,
-                   const Slice& tail,
-                   const Index64& advanced) const override;
-
-    const SliceJagged64
-      varaxis_to_jagged(const SliceVarNewAxis& varnewaxis) const override;
-
     /// @brief An utility function to create a new instance of NumpyArray on the
     /// GPU identical to this one.
     const ContentPtr
@@ -773,12 +766,6 @@ namespace awkward {
                           const SliceJagged64& slicecontent,
                           const Slice& tail) const override;
 
-    const ContentPtr
-      getitem_next_jagged(const Index64& slicestarts,
-                          const Index64& slicestops,
-                          const SliceVarNewAxis& slicecontent,
-                          const Slice& tail) const override;
-
     /// @brief Internal function to fill JSON with boolean values.
     void
       tojson_boolean(ToJson& builder, bool include_beginendlist) const;
@@ -810,6 +797,7 @@ namespace awkward {
     const std::shared_ptr<void> index_sort(const T* data,
                                            int64_t length,
                                            const Index64& starts,
+                                           const Index64& shifts,
                                            const Index64& parents,
                                            int64_t outlength,
                                            bool ascending,
@@ -830,14 +818,6 @@ namespace awkward {
                                              const Index64& parents,
                                              int64_t& outlength) const;
 
-    template<typename T>
-    const std::shared_ptr<void> string_sort(const T* data,
-                                            int64_t length,
-                                            const Index64& offsets,
-                                            Index64& outoffsets,
-                                            bool ascending,
-                                            bool stable) const;
-
     template<typename T>
     const std::shared_ptr<void> string_unique(const T* data,
                                               int64_t length,
