@@ -13,6 +13,9 @@
 #include "awkward/Content.h"
 
 namespace awkward {
+
+  class ByteMaskedArray;
+
   /// @class UnmaskedForm
   ///
   /// @brief Form describing UnmaskedArray.
@@ -72,6 +75,9 @@ namespace awkward {
     const std::vector<std::string>
       keys() const override;
 
+    bool
+      istuple() const override;
+
     bool
       equal(const FormPtr& other,
             bool check_identities,
@@ -254,6 +260,9 @@ namespace awkward {
     const std::vector<std::string>
       keys() const override;
 
+    bool
+      istuple() const override;
+
     // operations
     const std::string
       validityerror(const std::string& path) const override;
@@ -312,17 +321,16 @@ namespace awkward {
                 const Index64& parents,
                 int64_t outlength,
                 bool ascending,
-                bool stable,
-                bool keepdims) const override;
+                bool stable) const override;
 
     const ContentPtr
       argsort_next(int64_t negaxis,
                    const Index64& starts,
+                   const Index64& shifts,
                    const Index64& parents,
                    int64_t outlength,
                    bool ascending,
-                   bool stable,
-                   bool keepdims) const override;
+                   bool stable) const override;
 
     const ContentPtr
       localindex(int64_t axis, int64_t depth) const override;
@@ -373,20 +381,6 @@ namespace awkward {
                           const SliceJagged64& slicecontent,
                           const Slice& tail) const override;
 
-    const ContentPtr
-      getitem_next_jagged(const Index64& slicestarts,
-                          const Index64& slicestops,
-                          const SliceVarNewAxis& slicecontent,
-                          const Slice& tail) const override;
-
-    const ContentPtr
-      getitem_next(const SliceVarNewAxis& varnewaxis,
-                   const Slice& tail,
-                   const Index64& advanced) const override;
-
-    const SliceJagged64
-      varaxis_to_jagged(const SliceVarNewAxis& varnewaxis) const override;
-
     const ContentPtr
       copy_to(kernel::lib ptr_lib) const override;
 
