@@ -30,6 +30,7 @@ namespace awkward {
     ForthMachineOf(const std::string& source,
                    int64_t stack_max_depth=1024,
                    int64_t recursion_max_depth=1024,
+                   int64_t string_buffer_size=1024,
                    int64_t output_initial_size=1024,
                    double output_resize_factor=1.5);
 
@@ -49,7 +50,8 @@ namespace awkward {
 
     /// @brief HERE
     const std::string
-      decompiled_segment(int64_t segment_position, const std::string& indent="") const;
+      decompiled_segment(int64_t segment_position, const std::string& indent="",
+                         bool endline = true) const;
 
     /// @brief HERE
     const std::string
@@ -67,6 +69,10 @@ namespace awkward {
     int64_t
       recursion_max_depth() const noexcept;
 
+    /// @brief HERE
+    int64_t
+      string_buffer_size() const noexcept;
+
     /// @brief HERE
     int64_t
       output_initial_size() const noexcept;
@@ -226,6 +232,10 @@ namespace awkward {
     void
       begin();
 
+    ///@brief HERE
+    util::ForthError
+    begin_again(const std::map<std::string, std::shared_ptr<ForthInputBuffer>>& inputs, bool reset_instruction);
+
     /// @brief HERE
     util::ForthError
       step();
@@ -554,6 +564,9 @@ namespace awkward {
     std::vector<int64_t> bytecodes_offsets_;
     std::vector<I> bytecodes_;
 
+    char* string_buffer_;
+    int64_t string_buffer_size_;
+
     std::vector<std::shared_ptr<ForthInputBuffer>> current_inputs_;
     std::vector<std::shared_ptr<ForthOutputBuffer>> current_outputs_;
     bool is_ready_;
