@@ -237,17 +237,37 @@ namespace awkward {
   FormPtr
   fromjson_part(const JSON& json) {
     if (json.IsString()) {
-      util::dtype dtype = util::name_to_dtype(json.GetString());
-      int64_t itemsize = util::dtype_to_itemsize(dtype);
-      std::string format = util::dtype_to_format(dtype);
-      if (dtype != util::dtype::NOT_PRIMITIVE) {
+      std::string primitive(json.GetString());
+      if (primitive.find("datetime64") == 0) {
         return std::make_shared<NumpyForm>(false,
                                            util::Parameters(),
                                            FormKey(nullptr),
                                            std::vector<int64_t>(),
-                                           itemsize,
-                                           format,
-                                           dtype);
+                                           8,
+                                           "M8" + primitive.substr(10, std::string::npos),
+                                           util::dtype::datetime64);
+      }
+      else if (primitive.find("timedelta64") == 0) {
+        return std::make_shared<NumpyForm>(false,
+                                           util::Parameters(),
+                                           FormKey(nullptr),
+                                           std::vector<int64_t>(),
+                                           8,
+                                           "m8" + primitive.substr(11, std::string::npos),
+                                           util::dtype::timedelta64);
+      }
+      else {
+        util::dtype dtype = util::name_to_dtype(primitive);
+        int64_t itemsize = util::dtype_to_itemsize(dtype);
+        if (dtype != util::dtype::NOT_PRIMITIVE) {
+          return std::make_shared<NumpyForm>(false,
+                                             util::Parameters(),
+                                             FormKey(nullptr),
+                                             std::vector<int64_t>(),
+                                             itemsize,
+                                             util::dtype_to_format(dtype),
+                                             dtype);
+        }
       }
     }
 
@@ -319,6 +339,11 @@ namespace awkward {
           format = raw->format();
           itemsize = raw->itemsize();
           dtype = util::format_to_dtype(format, itemsize);
+          if ((raw->dtype() == util::dtype::datetime64 ||
+               raw->dtype() == util::dtype::timedelta64)
+              && json.HasMember("format")  &&  json["format"].IsString()) {
+            format = json["format"].GetString();
+          }
         }
         else if (json.HasMember("format")  &&  json["format"].IsString()  &&
                  json.HasMember("itemsize")  &&  json["itemsize"].IsInt()) {
@@ -1705,16 +1730,17 @@ namespace awkward {
       int64_t posaxis = depth + axis;
       if (posaxis < 0) {
         throw std::invalid_argument(
-          std::string("axis == ") + std::to_string(axis)
-                      + std::string(" exceeds the depth == ") + std::to_string(depth)
-                      + std::string(" of this array") + FILENAME(__LINE__));
+          std::string("axis=") + std::to_string(axis)
+                      + std::string(" exceeds the depth (") + std::to_string(depth)
+                      + std::string(") of this array") + FILENAME(__LINE__));
       }
       return posaxis;
     } else if (mindepth + axis == 0) {
       throw std::invalid_argument(
-        std::string("axis == ") + std::to_string(axis)
-                    + std::string(" exceeds the min depth == ") + std::to_string(mindepth)
-                    + std::string(" of this array") + FILENAME(__LINE__));
+        std::string("axis=") + std::to_string(axis)
+                    + std::string(" exceeds the depth (") + std::to_string(mindepth)
+                    + std::string(") of at least one record field (or union possibility) of this array")
+                    + FILENAME(__LINE__));
     }
     return axis;
   }
