@@ -17,11 +17,6 @@ namespace awkward {
 
   SliceItem::~SliceItem() = default;
 
-  const SliceItemPtr
-  SliceItem::carry(const Index64& carry) const {
-    return shallow_copy();
-  }
-
   ////////// SliceAt
 
   SliceAt::SliceAt(int64_t at)
@@ -257,23 +252,6 @@ namespace awkward {
                                              frombool_);
   }
 
-  template <typename T>
-  const SliceItemPtr
-  SliceArrayOf<T>::carry(const Index64& carry) const {
-    IndexOf<T> nextindex(carry.length());
-    struct Error err = kernel::Index_carry_64<T>(
-      kernel::lib::cpu,   // DERIVE
-      nextindex.data(),
-      index_.data(),
-      carry.data(),
-      index_.length(),
-      carry.length());
-    util::handle_error(err, "SliceArrayOf<T>", nullptr);
-    std::vector<int64_t> nextshape({ carry.length() });
-    nextshape.insert(nextshape.end(), shape_.begin() + 1, shape_.end());
-    return std::make_shared<SliceArrayOf<T>>(nextindex, nextshape, strides_, frombool_);
-  }
-
   template <typename T>
   const std::string
   SliceArrayOf<T>::tostring() const {
@@ -387,8 +365,8 @@ namespace awkward {
     if (std::is_same<T, int64_t>::value) {
       struct Error err = kernel::slicearray_ravel_64(
         kernel::lib::cpu,   // DERIVE
-        index.ptr().get(),
-        index_.ptr().get(),
+        index.data(),
+        index_.data(),
         ndim(),
         shape_.data(),
         strides_.data());
@@ -492,7 +470,14 @@ namespace awkward {
                                     const SliceItemPtr& content)
       : index_(index)
       , originalmask_(originalmask)
-      , content_(content) { }
+      , content_(content) {
+    if (dynamic_cast<SliceMissingOf<int64_t>*>(content.get())) {
+      throw std::runtime_error(
+        std::string("constructing SliceMissing directly inside of SliceMissing; "
+                    "is the array used as a slice valid (ak.validity_error(slice_array))?")
+        + FILENAME(__LINE__));
+    }
+  }
 
   template <typename T>
   int64_t
@@ -526,49 +511,6 @@ namespace awkward {
                                                content_);
   }
 
-  template <typename T>
-  const SliceItemPtr
-  SliceMissingOf<T>::carry(const Index64& carry) const {
-    IndexOf<T> nextindex(carry.length());
-    struct Error err1 = kernel::Index_carry_64<T>(
-      kernel::lib::cpu,   // DERIVE
-      nextindex.data(),
-      index_.data(),
-      carry.data(),
-      index_.length(),
-      carry.length());
-    util::handle_error(err1, "SliceMissingOf<T>", nullptr);
-
-    int64_t numnull;
-    struct Error err2 = kernel::IndexedArray_numnull<T>(
-      kernel::lib::cpu,   // DERIVE
-      &numnull,
-      nextindex.data(),
-      nextindex.length());
-    util::handle_error(err2, "SliceMissingOf<T>", nullptr);
-
-    Index64 nextcarry(nextindex.length() - numnull);
-    struct Error err3 = kernel::IndexedArray_flatten_nextcarry_64<T>(
-      kernel::lib::cpu,   // DERIVE
-      nextcarry.data(),
-      nextindex.data(),
-      nextindex.length(),
-      kMaxInt64);
-    util::handle_error(err3, "SliceMissingOf<T>", nullptr);
-
-    SliceItemPtr nextcontent = content_.get()->carry(nextcarry);
-    IndexOf<T> outindex(nextindex.length());
-
-    struct Error err = kernel::carry_SliceMissing_outindex<T>(
-      kernel::lib::cpu,   // DERIVE
-      outindex.data(),
-      nextindex.data(),
-      nextindex.length());
-    util::handle_error(err, "SliceJaggedOf<T>", nullptr);
-
-    return std::make_shared<SliceMissingOf<T>>(outindex, originalmask_, nextcontent);
-  }
-
   template <typename T>
   const std::string
   SliceMissingOf<T>::tostring() const {
@@ -660,33 +602,6 @@ namespace awkward {
     return std::make_shared<SliceJaggedOf<T>>(offsets_, content_);
   }
 
-  template <typename T>
-  const SliceItemPtr
-  SliceJaggedOf<T>::carry(const Index64& carry) const {
-    IndexOf<T> nextoffsets(carry.length() + 1);
-    int64_t nextcontentlen = 0;
-
-    struct Error err1 = kernel::carry_SliceJagged_offsets<T>(
-      kernel::lib::cpu,   // DERIVE
-      nextoffsets.data(),
-      offsets_.data(),
-      carry.data(),
-      carry.length());
-    util::handle_error(err1, "SliceJaggedOf<T>", nullptr);
-
-    Index64 nextcarry(nextoffsets.getitem_at_nowrap(carry.length()));
-    struct Error err2 = kernel::carry_SliceJagged_nextcarry<T>(
-      kernel::lib::cpu,   // DERIVE
-      nextcarry.data(),
-      offsets_.data(),
-      carry.data(),
-      carry.length());
-    util::handle_error(err2, "SliceJaggedOf<T>", nullptr);
-
-    SliceItemPtr nextcontent = content_.get()->carry(nextcarry);
-    return std::make_shared<SliceJaggedOf<T>>(nextoffsets, nextcontent);
-  }
-
   template <typename T>
   const std::string
   SliceJaggedOf<T>::tostring() const {
@@ -746,46 +661,6 @@ namespace awkward {
 
   template class EXPORT_TEMPLATE_INST SliceJaggedOf<int64_t>;
 
-  ////////// SliceVarNewAxis
-
-  SliceVarNewAxis::SliceVarNewAxis(const SliceItemPtr& content)
-      : content_(content) { }
-
-  const SliceItemPtr
-  SliceVarNewAxis::content() const {
-    return content_;
-  }
-
-  const SliceItemPtr
-  SliceVarNewAxis::shallow_copy() const {
-    return std::make_shared<SliceVarNewAxis>(content_);
-  }
-
-  const SliceItemPtr
-  SliceVarNewAxis::carry(const Index64& carry) const {
-    return std::make_shared<SliceVarNewAxis>(content_.get()->carry(carry));
-  }
-
-  const std::string
-  SliceVarNewAxis::tostring() const {
-    return std::string("newaxis(") + content_.get()->tostring() + std::string(")");
-  }
-
-  bool
-  SliceVarNewAxis::preserves_type(const Index64& advanced) const {
-    return true;
-  }
-
-  bool
-  SliceVarNewAxis::referentially_equal(const SliceItemPtr& other) const {
-    if (SliceVarNewAxis* raw = dynamic_cast<SliceVarNewAxis*>(other.get())) {
-      return content_.get()->referentially_equal(raw->content());
-    }
-    else {
-      return false;
-    }
-  }
-
   ////////// Slice
 
   int64_t Slice::none() {
