@@ -170,6 +170,11 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  bool
+  BitMaskedForm::istuple() const {
+    return content_.get()->istuple();
+  }
+
   bool
   BitMaskedForm::equal(const FormPtr& other,
                        bool check_identities,
@@ -789,6 +794,11 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  bool
+  BitMaskedArray::istuple() const {
+    return content_.get()->istuple();
+  }
+
   const std::string
   BitMaskedArray::validityerror(const std::string& path) const {
     const std::string paramcheck = validityerror_parameters(path);
