@@ -162,6 +162,11 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  bool
+  ByteMaskedForm::istuple() const {
+    return content_.get()->istuple();
+  }
+
   bool
   ByteMaskedForm::equal(const FormPtr& other,
                         bool check_identities,
@@ -821,6 +826,11 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  bool
+  ByteMaskedArray::istuple() const {
+    return content_.get()->istuple();
+  }
+
   const std::string
   ByteMaskedArray::validityerror(const std::string& path) const {
     const std::string paramcheck = validityerror_parameters(path);
