@@ -181,6 +181,11 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  bool
+  ListOffsetForm::istuple() const {
+    return content_.get()->istuple();
+  }
+
   bool
   ListOffsetForm::equal(const FormPtr& other,
                         bool check_identities,
@@ -911,6 +916,12 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  template <typename T>
+  bool
+  ListOffsetArrayOf<T>::istuple() const {
+    return content_.get()->istuple();
+  }
+
   template <typename T>
   const std::string
   ListOffsetArrayOf<T>::validityerror(const std::string& path) const {
@@ -1366,6 +1377,7 @@ namespace awkward {
     int64_t outlength,
     bool mask,
     bool keepdims) const {
+
     if (offsets_.getitem_at_nowrap(0) != 0) {
       ContentPtr next = toListOffsetArray64(true);
       return next.get()->reduce_next(
@@ -1520,6 +1532,7 @@ namespace awkward {
 
       ContentPtr trimmed = content_.get()->getitem_range_nowrap(globalstart,
                                                                 globalstop);
+
       ContentPtr outcontent = trimmed.get()->reduce_next(reducer,
                                                          negaxis,
                                                          util::make_starts(offsets_),
@@ -1914,10 +1927,6 @@ namespace awkward {
                                            int64_t outlength,
                                            bool ascending,
                                            bool stable) const {
-    if (length() == 0 ) {
-     return shallow_copy();
-    }
-
     std::pair<bool, int64_t> branchdepth = branch_depth();
 
     if (parameter_equals("__array__", "\"string\"")  ||
