@@ -308,6 +308,15 @@ namespace awkward {
     return shallow_copy();
   }
 
+  const int64_t
+  Record::axis_wrap_if_negative(int64_t axis) const {
+    if (axis == 0) {
+      throw std::invalid_argument(
+        std::string("Record at axis=0 is a scalar, not an array") + FILENAME(__LINE__));
+    }
+    return array_.get()->axis_wrap_if_negative(axis);
+  }
+
   const ContentPtr
   Record::num(int64_t axis, int64_t depth) const {
     int64_t posaxis = axis_wrap_if_negative(axis);
