@@ -168,6 +168,11 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  bool
+  RegularForm::istuple() const {
+    return content_.get()->istuple();
+  }
+
   bool
   RegularForm::equal(const FormPtr& other,
                      bool check_identities,
@@ -783,6 +788,11 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  bool
+  RegularArray::istuple() const {
+    return content_.get()->istuple();
+  }
+
   const std::string
   RegularArray::validityerror(const std::string& path) const {
     const std::string paramcheck = validityerror_parameters(path);
@@ -1054,6 +1064,7 @@ namespace awkward {
                             int64_t outlength,
                             bool mask,
                             bool keepdims) const {
+
     ContentPtr out = toListOffsetArray64(true).get()->reduce_next(reducer,
                                                                   negaxis,
                                                                   starts,
@@ -1068,6 +1079,7 @@ namespace awkward {
 
       bool convert_shallow = (negaxis == branchdepth.second);
       bool convert_deep = (negaxis + 2 == branchdepth.second);
+
       if (keepdims) {
         convert_shallow = false;
         convert_deep = true;
@@ -1307,9 +1319,6 @@ namespace awkward {
                              int64_t outlength,
                              bool ascending,
                              bool stable) const {
-    if (length() == 0) {
-      return std::make_shared<NumpyArray>(Index64(0));
-    }
     std::shared_ptr<Content> out = toListOffsetArray64(true).get()->argsort_next(
                                        negaxis,
                                        starts,
