@@ -137,6 +137,11 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  bool
+  UnmaskedForm::istuple() const {
+    return content_.get()->istuple();
+  }
+
   bool
   UnmaskedForm::equal(const FormPtr& other,
                       bool check_identities,
@@ -395,8 +400,7 @@ namespace awkward {
   }
 
   const TypePtr
-  UnmaskedArray::type(const std::map<std::string,
-                      std::string>& typestrs) const {
+  UnmaskedArray::type(const util::TypeStrs& typestrs) const {
     return form(true).get()->type(typestrs);
   }
 
@@ -690,6 +694,11 @@ namespace awkward {
     return content_.get()->keys();
   }
 
+  bool
+  UnmaskedArray::istuple() const {
+    return content_.get()->istuple();
+  }
+
   const std::string
   UnmaskedArray::validityerror(const std::string& path) const {
     const std::string paramcheck = validityerror_parameters(path);
@@ -998,9 +1007,6 @@ namespace awkward {
                               int64_t outlength,
                               bool ascending,
                               bool stable) const {
-    if (length() == 0) {
-      return std::make_shared<NumpyArray>(Index64(0));
-    }
     std::shared_ptr<Content> out = content_.get()->argsort_next(negaxis,
                                                                 starts,
                                                                 shifts,
