@@ -11,52 +11,54 @@
 
 namespace awkward {
   const BuilderPtr
-  Complex128Builder::fromempty(const ArrayBuilderOptions& options) {
+  Complex128Builder::fromempty(const BuilderOptions& options) {
     return std::make_shared<Complex128Builder>(options,
                                               GrowableBuffer<std::complex<double>>::empty(options));
   }
 
   const BuilderPtr
-  Complex128Builder::fromint64(const ArrayBuilderOptions& options,
+  Complex128Builder::fromint64(const BuilderOptions& options,
                                const GrowableBuffer<int64_t>& old) {
-    GrowableBuffer<std::complex<double>> buffer =
-      GrowableBuffer<std::complex<double>>::empty(options, old.reserved());
-    int64_t* oldraw = old.ptr().get();
-    std::complex<double>* newraw = buffer.ptr().get();
-    for (int64_t i = 0;  i < 2*old.length();  i++) {
-      newraw[i] = {static_cast<double>(oldraw[i]), 0};
-    }
-    buffer.set_length(old.length());
-    return std::make_shared<Complex128Builder>(options, buffer);
+    return std::make_shared<Complex128Builder>(
+      options,
+      std::move(GrowableBuffer<int64_t>::copy_as<std::complex<double>>(old)));
   }
 
   const BuilderPtr
-  Complex128Builder::fromfloat64(const ArrayBuilderOptions& options,
+  Complex128Builder::fromfloat64(const BuilderOptions& options,
                                  const GrowableBuffer<double>& old) {
-    GrowableBuffer<std::complex<double>> buffer =
-      GrowableBuffer<std::complex<double>>::empty(options, old.reserved());
-    double* oldraw = old.ptr().get();
-    std::complex<double>* newraw = buffer.ptr().get();
-    for (int64_t i = 0;  i < old.length();  i++) {
-      newraw[i] = std::complex<double>(oldraw[i], 0);
-    }
-    buffer.set_length(old.length());
-    return std::make_shared<Complex128Builder>(options, buffer);
+    return std::make_shared<Complex128Builder>(
+      options,
+      std::move(GrowableBuffer<double>::copy_as<std::complex<double>>(old)));
   }
 
-  Complex128Builder::Complex128Builder(const ArrayBuilderOptions& options,
-                                       const GrowableBuffer<std::complex<double>>& buffer)
+  Complex128Builder::Complex128Builder(const BuilderOptions& options,
+                                       GrowableBuffer<std::complex<double>> buffer)
       : options_(options)
-      , buffer_(buffer) { }
+      , buffer_(std::move(buffer)) { }
 
   const std::string
   Complex128Builder::classname() const {
     return "Complex128Builder";
   }
 
+  const std::string
+  Complex128Builder::to_buffers(BuffersContainer& container, int64_t& form_key_id) const {
+    std::stringstream form_key;
+    form_key << "node" << (form_key_id++);
+
+    void* ptr = container.empty_buffer(form_key.str() + "-data",
+      buffer_.length() * (int64_t)sizeof(std::complex<double>));
+
+    buffer_.concatenate(reinterpret_cast<std::complex<double>*>(ptr));
+
+    return "{\"class\": \"NumpyArray\", \"primitive\": \"complex128\", \"form_key\": \""
+           + form_key.str() + "\"}";
+  }
+
   int64_t
   Complex128Builder::length() const {
-    return buffer_.length();
+    return (int64_t)buffer_.length();
   }
 
   void
@@ -73,60 +75,60 @@ namespace awkward {
   Complex128Builder::null() {
     BuilderPtr out = OptionBuilder::fromvalids(options_, shared_from_this());
     out.get()->null();
-    return out;
+    return std::move(out);
   }
 
   const BuilderPtr
   Complex128Builder::boolean(bool x) {
     BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
     out.get()->boolean(x);
-    return out;
+    return std::move(out);
   }
 
   const BuilderPtr
   Complex128Builder::integer(int64_t x) {
     buffer_.append(std::complex<double>((double)x, 0));
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
   Complex128Builder::real(double x) {
     buffer_.append(std::complex<double>((double)x, 0));
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
   Complex128Builder::complex(std::complex<double> x) {
     buffer_.append(x);
-    return shared_from_this();
+    return nullptr;
   }
 
   const BuilderPtr
   Complex128Builder::datetime(int64_t x, const std::string& unit) {
     BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
     out.get()->datetime(x, unit);
-    return out;
+    return std::move(out);
   }
 
   const BuilderPtr
   Complex128Builder::timedelta(int64_t x, const std::string& unit) {
     BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
     out.get()->timedelta(x, unit);
-    return out;
+    return std::move(out);
   }
 
   const BuilderPtr
   Complex128Builder::string(const char* x, int64_t length, const char* encoding) {
     BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
     out.get()->string(x, length, encoding);
-    return out;
+    return std::move(out);
   }
 
   const BuilderPtr
   Complex128Builder::beginlist() {
     BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
     out.get()->beginlist();
-    return out;
+    return std::move(out);
   }
 
   const BuilderPtr
@@ -140,7 +142,7 @@ namespace awkward {
   Complex128Builder::begintuple(int64_t numfields) {
     BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
     out.get()->begintuple(numfields);
-    return out;
+    return std::move(out);
   }
 
   const BuilderPtr
@@ -161,10 +163,10 @@ namespace awkward {
   Complex128Builder::beginrecord(const char* name, bool check) {
     BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
     out.get()->beginrecord(name, check);
-    return out;
+    return std::move(out);
   }
 
-  const BuilderPtr
+  void
   Complex128Builder::field(const char* key, bool check) {
     throw std::invalid_argument(
       std::string("called 'field' without 'begin_record' at the same level before it")
@@ -176,10 +178,4 @@ namespace awkward {
     return shared_from_this();
   }
 
-  const BuilderPtr
-  Complex128Builder::append(const ContentPtr& array, int64_t at) {
-    BuilderPtr out = UnionBuilder::fromsingle(options_, shared_from_this());
-    out.get()->append(array, at);
-    return out;
-  }
 }
