@@ -211,10 +211,10 @@ namespace awkward {
       else if (fmt == std::string("Zg")) {
         return dtype::complex256;
       }
-      else if (fmt == std::string("M")) {
+      else if (fmt.substr(0, 2) == std::string("M8")) {
         return dtype::datetime64;
       }
-      else if (fmt == std::string("m")) {
+      else if (fmt.substr(0, 2) == std::string("m8")) {
         return dtype::timedelta64;
       }
       else {
