@@ -514,10 +514,10 @@ make_NumpyForm(const py::handle& m, const std::string& name) {
           dt = "c32";
           break;
         case ak::util::dtype::datetime64:
-          dt = "?";
+          dt = self.format();
           break;
         case ak::util::dtype::timedelta64:
-          dt = "?";
+          dt = self.format();
           break;
         default:
           // FIXME: record arrays; need to parse 'format'
@@ -598,11 +598,10 @@ make_RecordForm(const py::handle& m, const std::string& name) {
           py::arg("has_identities") = false,
           py::arg("parameters") = py::none(),
           py::arg("form_key") = py::none())
-      .def_property_readonly("contents", [](const ak::RecordForm& self)
-           -> std::map<std::string, std::shared_ptr<ak::Form>> {
-        std::map<std::string, std::shared_ptr<ak::Form>> out;
+      .def_property_readonly("contents", [](const ak::RecordForm& self) -> py::dict {
+        py::dict out;
         for (int64_t i = 0;  i < self.numfields();  i++) {
-          out[self.key(i)] = self.content(i);
+          out[py::str(self.key(i))] = py::cast(self.content(i));
         }
         return out;
       })
@@ -625,14 +624,14 @@ make_RecordForm(const py::handle& m, const std::string& name) {
       .def(py::pickle([](const ak::RecordForm& self) {
         py::object recordlookup = py::none();
         if (!self.istuple()) {
-          py::tuple recordlookup_tuple(self.numfields());
+          py::tuple recordlookup_tuple((py::ssize_t) self.numfields());
           for (int64_t i = 0;  i < self.numfields();  i++) {
             recordlookup_tuple[(size_t)i] =
               py::cast(self.recordlookup().get()->at((size_t)i));
           }
           recordlookup = recordlookup_tuple;
         }
-        py::tuple contents(self.numfields());
+        py::tuple contents((py::ssize_t) self.numfields());
         for (int64_t i = 0;  i < self.numfields();  i++) {
           contents[(size_t)i] = py::cast(self.content(i));
         }
@@ -743,7 +742,7 @@ make_UnionForm(const py::handle& m, const std::string& name) {
       .def_property_readonly("numcontents", &ak::UnionForm::numcontents)
       .def("content", &ak::UnionForm::content)
       .def(py::pickle([](const ak::UnionForm& self) {
-        py::tuple contents(self.numcontents());
+        py::tuple contents((py::ssize_t) self.numcontents());
         for (int64_t i = 0;  i < self.numcontents();  i++) {
           contents[(size_t)i] = py::cast(self.content(i));
         }
