@@ -22,7 +22,10 @@ py::object maybe_throw(const ak::ForthMachineOf<T, I>& self,
                        bool raise_skip_beyond,
                        bool raise_rewind_beyond,
                        bool raise_division_by_zero,
-                       bool raise_varint_too_big) {
+                       bool raise_varint_too_big,
+                       bool raise_text_number_missing,
+                       bool raise_quoted_string_missing,
+                       bool raise_enumeration_missing) {
   std::set<ak::util::ForthError> ignore;
   if (!raise_user_halt) {
     ignore.insert(ak::util::ForthError::user_halt);
@@ -54,6 +57,15 @@ py::object maybe_throw(const ak::ForthMachineOf<T, I>& self,
   if (!raise_varint_too_big) {
     ignore.insert(ak::util::ForthError::varint_too_big);
   }
+  if (!raise_text_number_missing) {
+    ignore.insert(ak::util::ForthError::text_number_missing);
+  }
+  if (!raise_quoted_string_missing) {
+    ignore.insert(ak::util::ForthError::quoted_string_missing);
+  }
+  if (!raise_enumeration_missing) {
+    ignore.insert(ak::util::ForthError::enumeration_missing);
+  }
   self.maybe_throw(err, ignore);
 
   switch (err) {
@@ -83,6 +95,12 @@ py::object maybe_throw(const ak::ForthMachineOf<T, I>& self,
       return py::str("division by zero");
     case ak::util::ForthError::varint_too_big:
       return py::str("varint too big");
+    case ak::util::ForthError::text_number_missing:
+      return py::str("text number missing");
+    case ak::util::ForthError::quoted_string_missing:
+      return py::str("quoted string missing");
+    case ak::util::ForthError::enumeration_missing:
+      return py::str("enumeration missing");
     default:
       throw std::invalid_argument(
           std::string("unrecognized ForthError: ")
@@ -98,18 +116,21 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
           .def(py::init([](const std::string& source,
                            int64_t stack_size,
                            int64_t recursion_depth,
+                           int64_t string_buffer_size,
                            int64_t output_initial_size,
                            double output_resize_factor)
                         -> std::shared_ptr<ak::ForthMachineOf<T, I>> {
             return std::make_shared<ak::ForthMachineOf<T, I>>(source,
                                                               stack_size,
                                                               recursion_depth,
+                                                              string_buffer_size,
                                                               output_initial_size,
                                                               output_resize_factor);
           }),
                py::arg("source"),
                py::arg("stack_size") = 1024,
                py::arg("recursion_depth") = 1024,
+               py::arg("string_buffer_size") = 1024,
                py::arg("output_initial_size") = 1024,
                py::arg("output_resize_factor") = 1.5)
           .def("__getitem__", [](const std::shared_ptr<ak::ForthMachineOf<T, I>>& self,
@@ -151,6 +172,8 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
               &ak::ForthMachineOf<T, I>::stack_max_depth)
           .def_property_readonly("recursion_max_depth",
               &ak::ForthMachineOf<T, I>::recursion_max_depth)
+          .def_property_readonly("string_buffer_size",
+              &ak::ForthMachineOf<T, I>::string_buffer_size)
           .def_property_readonly("output_initial_size",
               &ak::ForthMachineOf<T, I>::output_initial_size)
           .def_property_readonly("output_resize_factor",
@@ -238,6 +261,23 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
               }
               self.begin(ins);
           }, py::arg("inputs") = py::dict())
+          .def("begin_again", [](ak::ForthMachineOf<T, I>& self,
+                           const py::dict& inputs, bool reset_instruction) -> void {
+              std::map<std::string, std::shared_ptr<ak::ForthInputBuffer>> ins;
+              for (auto pair : inputs) {
+                std::string name = pair.first.cast<std::string>();
+                py::buffer obj = pair.second.cast<py::buffer>();
+                py::buffer_info info = obj.request(self.input_must_be_writable(name));
+                int64_t length = info.itemsize;
+                for (auto x : info.shape) {
+                  length *= x;
+                }
+                std::shared_ptr<void> ptr = std::shared_ptr<uint8_t>(
+                    reinterpret_cast<uint8_t*>(info.ptr), pyobject_deleter<uint8_t>(obj.ptr()));
+                ins[name] = std::make_shared<ak::ForthInputBuffer>(ptr, 0, length);
+              }
+              self.begin_again(ins, reset_instruction);
+          }, py::arg("inputs"), py::arg("reset_instruction") = true)
           .def("step", [](ak::ForthMachineOf<T, I>& self,
                           bool raise_user_halt,
                           bool raise_recursion_depth_exceeded,
@@ -248,7 +288,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
                           bool raise_skip_beyond,
                           bool raise_rewind_beyond,
                           bool raise_division_by_zero,
-                          bool raise_varint_too_big) -> py::object {
+                          bool raise_varint_too_big,
+                          bool raise_text_number_missing,
+                          bool raise_quoted_string_missing,
+                          bool raise_enumeration_missing) -> py::object {
               ak::util::ForthError err = self.step();
               return maybe_throw<T, I>(self,
                                        err,
@@ -261,7 +304,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
                                        raise_skip_beyond,
                                        raise_rewind_beyond,
                                        raise_division_by_zero,
-                                       raise_varint_too_big);
+                                       raise_varint_too_big,
+                                       raise_text_number_missing,
+                                       raise_quoted_string_missing,
+                                       raise_enumeration_missing);
           }, py::arg("raise_user_halt") = true
            , py::arg("raise_recursion_depth_exceeded") = true
            , py::arg("raise_stack_underflow") = true
@@ -271,7 +317,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
            , py::arg("raise_skip_beyond") = true
            , py::arg("raise_rewind_beyond") = true
            , py::arg("raise_division_by_zero") = true
-           , py::arg("raise_varint_too_big") = true)
+           , py::arg("raise_varint_too_big") = true
+           , py::arg("raise_text_number_missing") = true
+           , py::arg("raise_quoted_string_missing") = true
+           , py::arg("raise_enumeration_missing") = true)
           .def("run", [](ak::ForthMachineOf<T, I>& self,
                          const py::dict& inputs,
                          bool raise_user_halt,
@@ -283,7 +332,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
                          bool raise_skip_beyond,
                          bool raise_rewind_beyond,
                          bool raise_division_by_zero,
-                         bool raise_varint_too_big) -> py::object {
+                         bool raise_varint_too_big,
+                         bool raise_text_number_missing,
+                         bool raise_quoted_string_missing,
+                         bool raise_enumeration_missing) -> py::object {
               std::map<std::string, std::shared_ptr<ak::ForthInputBuffer>> ins;
               for (auto pair : inputs) {
                 std::string name = pair.first.cast<std::string>();
@@ -312,7 +364,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
                                        raise_skip_beyond,
                                        raise_rewind_beyond,
                                        raise_division_by_zero,
-                                       raise_varint_too_big);
+                                       raise_varint_too_big,
+                                       raise_text_number_missing,
+                                       raise_quoted_string_missing,
+                                       raise_enumeration_missing);
           }, py::arg("inputs") = py::dict()
            , py::arg("raise_user_halt") = true
            , py::arg("raise_recursion_depth_exceeded") = true
@@ -323,7 +378,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
            , py::arg("raise_skip_beyond") = true
            , py::arg("raise_rewind_beyond") = true
            , py::arg("raise_division_by_zero") = true
-           , py::arg("raise_varint_too_big") = true)
+           , py::arg("raise_varint_too_big") = true
+           , py::arg("raise_text_number_missing") = true
+           , py::arg("raise_quoted_string_missing") = true
+           , py::arg("raise_enumeration_missing") = true)
           .def("resume", [](ak::ForthMachineOf<T, I>& self,
                           bool raise_user_halt,
                           bool raise_recursion_depth_exceeded,
@@ -334,7 +392,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
                           bool raise_skip_beyond,
                           bool raise_rewind_beyond,
                           bool raise_division_by_zero,
-                          bool raise_varint_too_big) -> py::object {
+                          bool raise_varint_too_big,
+                          bool raise_text_number_missing,
+                          bool raise_quoted_string_missing,
+                          bool raise_enumeration_missing) -> py::object {
               py::gil_scoped_release release;
               ak::util::ForthError err = self.resume();
               py::gil_scoped_acquire acquire;
@@ -349,7 +410,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
                                        raise_skip_beyond,
                                        raise_rewind_beyond,
                                        raise_division_by_zero,
-                                       raise_varint_too_big);
+                                       raise_varint_too_big,
+                                       raise_text_number_missing,
+                                       raise_quoted_string_missing,
+                                       raise_enumeration_missing);
           }, py::arg("raise_user_halt") = true
            , py::arg("raise_recursion_depth_exceeded") = true
            , py::arg("raise_stack_underflow") = true
@@ -359,7 +423,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
            , py::arg("raise_skip_beyond") = true
            , py::arg("raise_rewind_beyond") = true
            , py::arg("raise_division_by_zero") = true
-           , py::arg("raise_varint_too_big") = true)
+           , py::arg("raise_varint_too_big") = true
+           , py::arg("raise_text_number_missing") = true
+           , py::arg("raise_quoted_string_missing") = true
+           , py::arg("raise_enumeration_missing") = true)
           .def("call", [](ak::ForthMachineOf<T, I>& self,
                           const std::string& name,
                           bool raise_user_halt,
@@ -371,7 +438,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
                           bool raise_skip_beyond,
                           bool raise_rewind_beyond,
                           bool raise_division_by_zero,
-                          bool raise_varint_too_big) -> py::object {
+                          bool raise_varint_too_big,
+                          bool raise_text_number_missing,
+                          bool raise_quoted_string_missing,
+                          bool raise_enumeration_missing) -> py::object {
               py::gil_scoped_release release;
               ak::util::ForthError err = self.call(name);
               py::gil_scoped_acquire acquire;
@@ -386,7 +456,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
                                        raise_skip_beyond,
                                        raise_rewind_beyond,
                                        raise_division_by_zero,
-                                       raise_varint_too_big);
+                                       raise_varint_too_big,
+                                       raise_text_number_missing,
+                                       raise_quoted_string_missing,
+                                       raise_enumeration_missing);
           }, py::arg("name")
            , py::arg("raise_user_halt") = true
            , py::arg("raise_recursion_depth_exceeded") = true
@@ -397,7 +470,10 @@ make_ForthMachineOf(const py::handle& m, const std::string& name) {
            , py::arg("raise_skip_beyond") = true
            , py::arg("raise_rewind_beyond") = true
            , py::arg("raise_division_by_zero") = true
-           , py::arg("raise_varint_too_big") = true)
+           , py::arg("raise_varint_too_big") = true
+           , py::arg("raise_text_number_missing") = true
+           , py::arg("raise_quoted_string_missing") = true
+           , py::arg("raise_enumeration_missing") = true)
           .def_property_readonly("current_bytecode_position",
               &ak::ForthMachineOf<T, I>::current_bytecode_position)
           .def_property_readonly("current_recursion_depth",
