@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import sys
 import gc
 
@@ -24,7 +22,7 @@ def test_refcount1():
 
     assert (sys.getrefcount(i), sys.getrefcount(i2)) == (
         3,
-        2 + (2 if ak._util.py27 else 1),
+        2 + 1,
     )
 
     del tmp
@@ -35,7 +33,7 @@ def test_refcount1():
 
     assert (sys.getrefcount(i), sys.getrefcount(i2)) == (
         3,
-        2 + (2 if ak._util.py27 else 1),
+        2 + 1,
     )
 
     del tmp2
