@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -151,11 +149,10 @@ def test_numpyarray_getitem_bystrides():
         a[np.newaxis, :, np.newaxis, :, np.newaxis]
     )
 
-    if not ak._util.py27:
-        assert ak.to_list(b[Ellipsis, 3]) == ak.to_list(a[Ellipsis, 3])
-        assert ak.to_list(b[Ellipsis, 3, 2]) == ak.to_list(a[Ellipsis, 3, 2])
-        assert ak.to_list(b[3, Ellipsis]) == ak.to_list(a[3, Ellipsis])
-        assert ak.to_list(b[3, 2, Ellipsis]) == ak.to_list(a[3, 2, Ellipsis])
+    assert ak.to_list(b[Ellipsis, 3]) == ak.to_list(a[Ellipsis, 3])
+    assert ak.to_list(b[Ellipsis, 3, 2]) == ak.to_list(a[Ellipsis, 3, 2])
+    assert ak.to_list(b[3, Ellipsis]) == ak.to_list(a[3, Ellipsis])
+    assert ak.to_list(b[3, 2, Ellipsis]) == ak.to_list(a[3, 2, Ellipsis])
 
 
 def test_numpyarray_contiguous():
@@ -234,6 +231,5 @@ def test_numpyarray_getitem_next():
     assert ak.to_list(b[c, np.newaxis, np.newaxis, 1:4]) == ak.to_list(
         a[c, np.newaxis, np.newaxis, 1:4]
     )
-    if not ak._util.py27:
-        assert ak.to_list(b[Ellipsis, c]) == ak.to_list(a[Ellipsis, c])
-        assert ak.to_list(b[c, Ellipsis]) == ak.to_list(a[c, Ellipsis])
+    assert ak.to_list(b[Ellipsis, c]) == ak.to_list(a[Ellipsis, c])
+    assert ak.to_list(b[c, Ellipsis]) == ak.to_list(a[c, Ellipsis])
