@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -353,17 +351,15 @@ def test_getitem_basic():
     )
     array = ak.partition.IrregularlyPartitionedArray([one, two])
 
-    if not ak._util.py27 and not ak._util.py35:
-        assert (
-            array.tojson()
-            == '[{"x":0.0,"y":[]},{"x":1.1,"y":[1]},{"x":2.2,"y":[2,2]},{"x":3.3,"y":[3,3,3]},{"x":4.4,"y":[4,4,4,4]}]'
-        )
-        assert array["x"].tojson() == "[0.0,1.1,2.2,3.3,4.4]"
-        assert array["y"].tojson() == "[[],[1],[2,2],[3,3,3],[4,4,4,4]]"
-        assert (
-            array[["x"]].tojson()
-            == '[{"x":0.0},{"x":1.1},{"x":2.2},{"x":3.3},{"x":4.4}]'
-        )
+    assert (
+        array.tojson()
+        == '[{"x":0.0,"y":[]},{"x":1.1,"y":[1]},{"x":2.2,"y":[2,2]},{"x":3.3,"y":[3,3,3]},{"x":4.4,"y":[4,4,4,4]}]'
+    )
+    assert array["x"].tojson() == "[0.0,1.1,2.2,3.3,4.4]"
+    assert array["y"].tojson() == "[[],[1],[2,2],[3,3,3],[4,4,4,4]]"
+    assert (
+        array[["x"]].tojson() == '[{"x":0.0},{"x":1.1},{"x":2.2},{"x":3.3},{"x":4.4}]'
+    )
 
 
 def test_getitem_first_dimension_int():
@@ -371,42 +367,30 @@ def test_getitem_first_dimension_int():
     two = ak.from_iter([[6.6], [], [], [], [7.7, 8.8, 9.9]], highlevel=False)
     array = ak.partition.IrregularlyPartitionedArray([one, two])
 
-    assert (
-        ak.to_list(
-            array[
-                0,
-            ]
-        )
-        == [1.1, 2.2, 3.3]
-    )
-    assert (
-        ak.to_list(
-            array[
-                -8,
-            ]
-        )
-        == [1.1, 2.2, 3.3]
-    )
+    assert ak.to_list(
+        array[
+            0,
+        ]
+    ) == [1.1, 2.2, 3.3]
+    assert ak.to_list(
+        array[
+            -8,
+        ]
+    ) == [1.1, 2.2, 3.3]
     assert array[0, 1] == 2.2
     assert array[-8, 1] == 2.2
     assert ak.to_list(array[0, [-1, 0]]) == [3.3, 1.1]
     assert ak.to_list(array[0, [False, True, True]]) == [2.2, 3.3]
-    assert (
-        ak.to_list(
-            array[
-                7,
-            ]
-        )
-        == [7.7, 8.8, 9.9]
-    )
-    assert (
-        ak.to_list(
-            array[
-                -1,
-            ]
-        )
-        == [7.7, 8.8, 9.9]
-    )
+    assert ak.to_list(
+        array[
+            7,
+        ]
+    ) == [7.7, 8.8, 9.9]
+    assert ak.to_list(
+        array[
+            -1,
+        ]
+    ) == [7.7, 8.8, 9.9]
     assert array[7, 1] == 8.8
     assert array[-1, 1] == 8.8
     assert ak.to_list(array[7, [-1, 0]]) == [9.9, 7.7]
@@ -446,11 +430,10 @@ def test_getitem_first_dimension_field():
     )
     array = ak.partition.IrregularlyPartitionedArray([one, two])
 
-    if not ak._util.py27 and not ak._util.py35:
-        assert (
-            array.tojson()
-            == '[{"x":0.0,"y":[]},{"x":1.1,"y":[1]},{"x":2.2,"y":[2,2]},{"x":3.3,"y":[3,3,3]},{"x":4.4,"y":[4,4,4,4]}]'
-        )
+    assert (
+        array.tojson()
+        == '[{"x":0.0,"y":[]},{"x":1.1,"y":[1]},{"x":2.2,"y":[2,2]},{"x":3.3,"y":[3,3,3]},{"x":4.4,"y":[4,4,4,4]}]'
+    )
     assert array["y", :, :2].tojson() == "[[],[1],[2,2],[3,3],[4,4]]"
     assert (
         array[["y"], :, :2].tojson()
@@ -857,9 +840,8 @@ def test_zip():
         {"x": [6], "y": 4.4},
         {"x": [7, 8, 9, 10], "y": 5.5},
     ]
-    if not ak._util.py27 and not ak._util.py35:
-        assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
-        assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
+    assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
+    assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
 
     x = ak.repartition(x, 3)
     assert isinstance(x.layout, ak.partition.PartitionedArray)
@@ -891,9 +873,8 @@ def test_zip():
         {"x": [6], "y": 4.4},
         {"x": [7, 8, 9, 10], "y": 5.5},
     ]
-    if not ak._util.py27 and not ak._util.py35:
-        assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
-        assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
+    assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
+    assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
 
     y = ak.repartition(y, 2)
     assert isinstance(x.layout, ak.partition.PartitionedArray)
@@ -925,9 +906,8 @@ def test_zip():
         {"x": [6], "y": 4.4},
         {"x": [7, 8, 9, 10], "y": 5.5},
     ]
-    if not ak._util.py27 and not ak._util.py35:
-        assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
-        assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
+    assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
+    assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
 
     x = ak.repartition(x, None)
     assert isinstance(x.layout, ak.layout.Content)
@@ -959,9 +939,8 @@ def test_zip():
         {"x": [6], "y": 4.4},
         {"x": [7, 8, 9, 10], "y": 5.5},
     ]
-    if not ak._util.py27 and not ak._util.py35:
-        assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
-        assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
+    assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
+    assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
 
     y = ak.repartition(y, None)
     assert isinstance(y.layout, ak.layout.Content)
@@ -993,9 +972,8 @@ def test_zip():
         {"x": [6], "y": 4.4},
         {"x": [7, 8, 9, 10], "y": 5.5},
     ]
-    if not ak._util.py27 and not ak._util.py35:
-        assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
-        assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
+    assert ak.to_list(xx) == [[1, 2, 3], [], [4, 5], [6], [7, 8, 9, 10]]
+    assert ak.to_list(yy) == [1.1, 2.2, 3.3, 4.4, 5.5]
 
 
 def test_with_name_field():
