@@ -1,15 +1,8 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import json
 
-try:
-    # pybind11 only supports cPickle protocol 2+ (-1 in pickle.dumps)
-    # (automatically satisfied in Python 3; this is just to keep testing Python 2.7)
-    import cPickle as pickle
-except ImportError:
-    import pickle
+import pickle
 
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
@@ -441,30 +434,29 @@ def test_forms():
         "parameters": {"hey": ["you"]},
         "form_key": "yowzers",
     }
-    if not ak._util.py27 and not ak._util.py35:
-        assert [json.loads(str(x)) for x in form.values()] == [
-            {
-                "class": "NumpyArray",
-                "itemsize": 8,
-                "format": "d",
-                "primitive": "float64",
-            },
-            {"class": "NumpyArray", "itemsize": 1, "format": "?", "primitive": "bool"},
-        ]
-        assert {n: json.loads(str(x)) for n, x in form.contents.items()} == {
-            "one": {
-                "class": "NumpyArray",
-                "itemsize": 8,
-                "format": "d",
-                "primitive": "float64",
-            },
-            "two": {
-                "class": "NumpyArray",
-                "itemsize": 1,
-                "format": "?",
-                "primitive": "bool",
-            },
-        }
+    assert [json.loads(str(x)) for x in form.values()] == [
+        {
+            "class": "NumpyArray",
+            "itemsize": 8,
+            "format": "d",
+            "primitive": "float64",
+        },
+        {"class": "NumpyArray", "itemsize": 1, "format": "?", "primitive": "bool"},
+    ]
+    assert {n: json.loads(str(x)) for n, x in form.contents.items()} == {
+        "one": {
+            "class": "NumpyArray",
+            "itemsize": 8,
+            "format": "d",
+            "primitive": "float64",
+        },
+        "two": {
+            "class": "NumpyArray",
+            "itemsize": 1,
+            "format": "?",
+            "primitive": "bool",
+        },
+    }
     assert json.loads(str(form.content("one"))) == {
         "class": "NumpyArray",
         "itemsize": 8,
@@ -477,19 +469,18 @@ def test_forms():
         "format": "?",
         "primitive": "bool",
     }
-    if not ak._util.py27 and not ak._util.py35:
-        assert json.loads(str(form.content(0))) == {
-            "class": "NumpyArray",
-            "itemsize": 8,
-            "format": "d",
-            "primitive": "float64",
-        }
-        assert json.loads(str(form.content(1))) == {
-            "class": "NumpyArray",
-            "itemsize": 1,
-            "format": "?",
-            "primitive": "bool",
-        }
+    assert json.loads(str(form.content(0))) == {
+        "class": "NumpyArray",
+        "itemsize": 8,
+        "format": "d",
+        "primitive": "float64",
+    }
+    assert json.loads(str(form.content(1))) == {
+        "class": "NumpyArray",
+        "itemsize": 1,
+        "format": "?",
+        "primitive": "bool",
+    }
     assert form.has_identities is False
     assert form.parameters == {"hey": ["you"]}
     assert form.parameter("hey") == ["you"]
