@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -76,8 +74,8 @@ def test_listarray():
         counter = [0]
 
         def materialize():
-            counter[0] += 1
-            return layout
+            counter[0] += 1  # noqa: B023
+            return layout  # noqa: B023
 
         generator = ak.layout.ArrayGenerator(
             materialize, form=layout.form, length=len(layout)
