@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import sys
 import operator
 
@@ -14,346 +12,6 @@ numba = pytest.importorskip("numba")
 ak_numba_arrayview = pytest.importorskip("awkward._connect._numba.arrayview")
 
 
-def test_ArrayBuilder_append():
-    array = ak.Array(
-        [[0.0, 1.1, 2.2], [], [3.3, 4.4], [5.5], [6.6, 7.7, 8.8, 9.9]], check_valid=True
-    )
-
-    builder = ak.ArrayBuilder()
-    builder.append(array, 3)
-    builder.append(array, 2)
-    builder.append(array, 2)
-    builder.append(array, 0)
-    builder.append(array, 1)
-    builder.append(array, -1)
-    assert ak.to_list(builder.snapshot()) == [
-        [5.5],
-        [3.3, 4.4],
-        [3.3, 4.4],
-        [0.0, 1.1, 2.2],
-        [],
-        [6.6, 7.7, 8.8, 9.9],
-    ]
-
-    builder.extend(array)
-    assert ak.to_list(builder.snapshot()) == [
-        [5.5],
-        [3.3, 4.4],
-        [3.3, 4.4],
-        [0.0, 1.1, 2.2],
-        [],
-        [6.6, 7.7, 8.8, 9.9],
-        [0.0, 1.1, 2.2],
-        [],
-        [3.3, 4.4],
-        [5.5],
-        [6.6, 7.7, 8.8, 9.9],
-    ]
-
-    builder = ak.ArrayBuilder()
-    builder.null()
-    builder.null()
-    builder.null()
-    builder.append(array, 3)
-    builder.append(array, 2)
-    builder.append(array, 2)
-    builder.append(array, -1)
-
-    assert ak.to_list(builder.snapshot()) == [
-        None,
-        None,
-        None,
-        [5.5],
-        [3.3, 4.4],
-        [3.3, 4.4],
-        [6.6, 7.7, 8.8, 9.9],
-    ]
-
-    builder.null()
-    assert ak.to_list(builder.snapshot()) == [
-        None,
-        None,
-        None,
-        [5.5],
-        [3.3, 4.4],
-        [3.3, 4.4],
-        [6.6, 7.7, 8.8, 9.9],
-        None,
-    ]
-
-    one = ak.Array(
-        [[0.0, 1.1, 2.2], [], [3.3, 4.4], [5.5], [6.6, 7.7, 8.8, 9.9]], check_valid=True
-    )
-    two = ak.Array([[3.3, 2.2, 1.1, 0.0], [5.5, 4.4], [], [6.6]], check_valid=True)
-
-    builder = ak.ArrayBuilder()
-    builder.append(one, 2)
-    builder.append(two, 1)
-    builder.append(one, 0)
-    builder.append(two, -1)
-    builder.append(one, -1)
-
-    assert ak.to_list(builder.snapshot()) == [
-        [3.3, 4.4],
-        [5.5, 4.4],
-        [0.0, 1.1, 2.2],
-        [6.6],
-        [6.6, 7.7, 8.8, 9.9],
-    ]
-
-    builder = ak.ArrayBuilder()
-    builder.null()
-    builder.append(one, 2)
-    builder.null()
-    builder.append(two, 1)
-    builder.null()
-    assert ak.to_list(builder.snapshot()) == [None, [3.3, 4.4], None, [5.5, 4.4], None]
-
-    builder = ak.ArrayBuilder()
-    builder.string("hello")
-    builder.append(one, 2)
-    builder.string("there")
-    builder.append(one, 0)
-    assert ak.to_list(builder.snapshot()) == [
-        "hello",
-        [3.3, 4.4],
-        "there",
-        [0.0, 1.1, 2.2],
-    ]
-
-    builder = ak.ArrayBuilder()
-    builder.null()
-    builder.string("hello")
-    builder.null()
-    builder.append(one, 2)
-    builder.null()
-    builder.string("there")
-    builder.append(one, 0)
-    assert ak.to_list(builder.snapshot()) == [
-        None,
-        "hello",
-        None,
-        [3.3, 4.4],
-        None,
-        "there",
-        [0.0, 1.1, 2.2],
-    ]
-
-    builder = ak.ArrayBuilder()
-    builder.append(one, 2)
-    builder.string("there")
-    builder.append(one, 0)
-    assert ak.to_list(builder.snapshot()) == [[3.3, 4.4], "there", [0.0, 1.1, 2.2]]
-
-    builder = ak.ArrayBuilder()
-    builder.null()
-    builder.append(one, 2)
-    builder.null()
-    builder.string("there")
-    builder.null()
-    builder.append(one, 0)
-    assert ak.to_list(builder.snapshot()) == [
-        None,
-        [3.3, 4.4],
-        None,
-        "there",
-        None,
-        [0.0, 1.1, 2.2],
-    ]
-
-    array = ak.Array(
-        [
-            "zero",
-            "one",
-            "two",
-            "three",
-            "four",
-            "five",
-            "six",
-            "seven",
-            "eight",
-            "nine",
-        ],
-        check_valid=True,
-    )
-    builder = ak.ArrayBuilder()
-    builder.begin_list()
-    builder.append(array, 1)
-    builder.append(array, 2)
-    builder.append(array, 3)
-    builder.end_list()
-    builder.begin_list()
-    builder.end_list()
-    builder.begin_list()
-    builder.append(array, 4)
-    builder.append(array, 5)
-    builder.end_list()
-    assert ak.to_list(builder.snapshot()) == [
-        ["one", "two", "three"],
-        [],
-        ["four", "five"],
-    ]
-
-    builder.append(array, -1)
-    assert ak.to_list(builder.snapshot()) == [
-        ["one", "two", "three"],
-        [],
-        ["four", "five"],
-        "nine",
-    ]
-
-    array = ak.Array(
-        [
-            {"x": 0.0, "y": []},
-            {"x": 1.1, "y": [1]},
-            {"x": 2.2, "y": [2, 2]},
-            {"x": 3.3, "y": [3, 3, 3]},
-        ],
-        check_valid=True,
-    )
-    builder = ak.ArrayBuilder()
-    builder.append(array[2])
-    builder.append(array[2])
-    builder.append(array[1])
-    builder.append(array[-1])
-    tmp = builder.snapshot()
-    assert ak.to_list(tmp) == [
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 1.1, "y": [1]},
-        {"x": 3.3, "y": [3, 3, 3]},
-    ]
-    assert isinstance(tmp.layout, ak.layout.IndexedArray64)
-    assert isinstance(tmp.layout.content, ak.layout.RecordArray)
-
-    builder.extend(array)
-    tmp = builder.snapshot()
-    assert ak.to_list(tmp) == [
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 1.1, "y": [1]},
-        {"x": 3.3, "y": [3, 3, 3]},
-        {"x": 0.0, "y": []},
-        {"x": 1.1, "y": [1]},
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 3.3, "y": [3, 3, 3]},
-    ]
-    assert isinstance(tmp.layout, ak.layout.IndexedArray64)
-    assert isinstance(tmp.layout.content, ak.layout.RecordArray)
-
-    builder.append(999)
-    tmp = builder.snapshot()
-    assert ak.to_list(tmp) == [
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 1.1, "y": [1]},
-        {"x": 3.3, "y": [3, 3, 3]},
-        {"x": 0.0, "y": []},
-        {"x": 1.1, "y": [1]},
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 3.3, "y": [3, 3, 3]},
-        999,
-    ]
-    assert isinstance(tmp.layout, ak.layout.UnionArray8_64)
-
-    builder.append([1, 2, 3, 4, 5])
-    tmp = builder.snapshot()
-    assert ak.to_list(tmp) == [
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 1.1, "y": [1]},
-        {"x": 3.3, "y": [3, 3, 3]},
-        {"x": 0.0, "y": []},
-        {"x": 1.1, "y": [1]},
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 3.3, "y": [3, 3, 3]},
-        999,
-        [1, 2, 3, 4, 5],
-    ]
-    assert isinstance(tmp.layout, ak.layout.UnionArray8_64)
-
-    array1 = ak.Array([[1.1, 2.2, 3.3], [], [4.4, 5.5]], check_valid=True)
-
-    builder = ak.ArrayBuilder()
-    builder.append(array1, 2)
-    builder.append(array1, 1)
-    builder.append(array1, 0)
-    array2 = builder.snapshot()
-    assert isinstance(array2.layout.content, ak.layout.ListOffsetArray64)
-
-    builder = ak.ArrayBuilder()
-    builder.append(array2, 2)
-    builder.append(array2, 1)
-    builder.append(array2, 0)
-    array3 = builder.snapshot()
-    assert isinstance(array3.layout.content, ak.layout.ListOffsetArray64)
-
-    builder = ak.ArrayBuilder()
-    builder.append(array3, 2)
-    builder.append(array3, 1)
-    builder.append(array3, 0)
-    array4 = builder.snapshot()
-    assert isinstance(array4.layout.content, ak.layout.ListOffsetArray64)
-
-
-def test_ArrayBuilder_append_2():
-    # issue #415
-    A = ak.from_numpy(np.array([0, 1, 2], dtype=np.float32))
-    B = ak.from_numpy(np.array([0, 1], dtype=np.float32))
-
-    builder = ak.ArrayBuilder()
-    with builder.list():
-        builder.append(A.tolist())
-    with builder.list():
-        builder.append(A.tolist())
-    with builder.list():
-        pass
-    with builder.list():
-        builder.append(B.tolist())
-
-    assert builder.snapshot().tolist() == [[[0, 1, 2]], [[0, 1, 2]], [], [[0, 1]]]
-    assert str(ak.type(builder.snapshot())) == "4 * var * var * float64"
-
-    builder = ak.ArrayBuilder()
-    with builder.list():
-        builder.append(A)
-    with builder.list():
-        builder.append(A)
-    with builder.list():
-        pass
-    with builder.list():
-        builder.append(B)
-
-    assert builder.snapshot().tolist() == [[[0, 1, 2]], [[0, 1, 2]], [], [[0, 1]]]
-    assert str(ak.type(builder.snapshot())) == "4 * var * var * float32"
-
-    @numba.njit
-    def f1(builder, A, B):
-        builder.begin_list()
-        builder.append(A)
-        builder.end_list()
-
-        builder.begin_list()
-        builder.append(A)
-        builder.end_list()
-
-        builder.begin_list()
-        builder.end_list()
-
-        builder.begin_list()
-        builder.append(B)
-        builder.end_list()
-
-        return builder
-
-    assert f1(ak.ArrayBuilder(), A, B).snapshot().tolist() == [
-        [[0, 1, 2]],
-        [[0, 1, 2]],
-        [],
-        [[0, 1]],
-    ]
-
-
 def test_views():
     assert ak.to_list(
         ak_numba_arrayview.ArrayView.fromarray(
@@ -379,21 +37,18 @@ def test_views():
         ).toarray()
     ) == [1.1, 2.2, None, 3.3, None, 4.4, 5.5]
 
-    assert (
-        ak.to_list(
-            ak_numba_arrayview.ArrayView.fromarray(
-                ak.Array(
-                    [
-                        {"x": 0.0, "y": []},
-                        {"x": 1.1, "y": [1, 1]},
-                        {"x": 2.2, "y": [2, 2, 2]},
-                    ],
-                    check_valid=True,
-                )
-            ).toarray()
-        )
-        == [{"x": 0.0, "y": []}, {"x": 1.1, "y": [1, 1]}, {"x": 2.2, "y": [2, 2, 2]}]
-    )
+    assert ak.to_list(
+        ak_numba_arrayview.ArrayView.fromarray(
+            ak.Array(
+                [
+                    {"x": 0.0, "y": []},
+                    {"x": 1.1, "y": [1, 1]},
+                    {"x": 2.2, "y": [2, 2, 2]},
+                ],
+                check_valid=True,
+            )
+        ).toarray()
+    ) == [{"x": 0.0, "y": []}, {"x": 1.1, "y": [1, 1]}, {"x": 2.2, "y": [2, 2, 2]}]
 
     assert ak.to_list(
         ak_numba_arrayview.ArrayView.fromarray(
@@ -1600,126 +1255,6 @@ def test_custom_record5():
     assert f2(array, 2) == 3.3
 
 
-def test_ArrayBuilder_append_numba():
-    @numba.njit
-    def f1(array, builder):
-        builder.append(array, 3)
-        builder.append(array, 2)
-        builder.append(array, 2)
-        builder.append(array, 0)
-        builder.append(array, 1)
-        builder.append(array, -1)
-
-    array = ak.Array(
-        [[0.0, 1.1, 2.2], [], [3.3, 4.4], [5.5], [6.6, 7.7, 8.8, 9.9]], check_valid=True
-    )
-    builder = ak.ArrayBuilder()
-
-    f1(array, builder)
-
-    assert ak.to_list(builder.snapshot()) == [
-        [5.5],
-        [3.3, 4.4],
-        [3.3, 4.4],
-        [0.0, 1.1, 2.2],
-        [],
-        [6.6, 7.7, 8.8, 9.9],
-    ]
-
-
-def test_ArrayBuilder_append_numba2():
-    @numba.njit
-    def f1(array, builder):
-        builder.append(array[3])
-        builder.append(array[2])
-        builder.append(array[2])
-        builder.append(array[0])
-        builder.append(array[1])
-        builder.append(array[-1])
-
-    array = ak.Array(
-        [
-            {"x": 0.0, "y": []},
-            {"x": 1.1, "y": [1]},
-            {"x": 2.2, "y": [2, 2]},
-            {"x": 3.3, "y": [3, 3, 3]},
-        ],
-        check_valid=True,
-    )
-    builder = ak.ArrayBuilder()
-
-    f1(array, builder)
-
-    assert ak.to_list(builder.snapshot()) == [
-        {"x": 3.3, "y": [3, 3, 3]},
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 2.2, "y": [2, 2]},
-        {"x": 0.0, "y": []},
-        {"x": 1.1, "y": [1]},
-        {"x": 3.3, "y": [3, 3, 3]},
-    ]
-
-
-def test_ArrayBuilder_append_numba3():
-    @numba.njit
-    def f1(array, builder):
-        builder.extend(array[3])
-        builder.extend(array[2])
-        builder.extend(array[2])
-        builder.extend(array[0])
-        builder.extend(array[1])
-        builder.extend(array[-1])
-
-    array = ak.Array(
-        [[0.0, 1.1, 2.2], [], [3.3, 4.4], [5.5], [6.6, 7.7, 8.8, 9.9]], check_valid=True
-    )
-    builder = ak.ArrayBuilder()
-
-    f1(array, builder)
-
-    assert ak.to_list(builder.snapshot()) == [
-        5.5,
-        3.3,
-        4.4,
-        3.3,
-        4.4,
-        0.0,
-        1.1,
-        2.2,
-        6.6,
-        7.7,
-        8.8,
-        9.9,
-    ]
-
-
-def test_ArrayBuilder_append_numba4():
-    @numba.njit
-    def f1(array, builder):
-        builder.append(array[3])
-        builder.append(array[2])
-        builder.append(array[2])
-        builder.append(array[0])
-        builder.append(array[1])
-        builder.append(array[-1])
-
-    array = ak.Array(
-        [[0.0, 1.1, 2.2], [], [3.3, 4.4], [5.5], [6.6, 7.7, 8.8, 9.9]], check_valid=True
-    )
-    builder = ak.ArrayBuilder()
-
-    f1(array, builder)
-
-    assert ak.to_list(builder.snapshot()) == [
-        [5.5],
-        [3.3, 4.4],
-        [3.3, 4.4],
-        [0.0, 1.1, 2.2],
-        [],
-        [6.6, 7.7, 8.8, 9.9],
-    ]
-
-
 def test_ArrayBuilder_append_numba5():
     @numba.njit
     def f1(builder, x):
