@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -30,11 +28,8 @@ def test():
         == []
     )
     assert ak.to_list(array[empty2]) == [[], [], []]
-    assert (
-        ak.to_list(
-            array[
-                empty2,
-            ]
-        )
-        == [[], [], []]
-    )
+    assert ak.to_list(
+        array[
+            empty2,
+        ]
+    ) == [[], [], []]
