@@ -1,16 +1,10 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
 
 
-@pytest.mark.skipif(
-    ak._util.py27 and ak._util.win,
-    reason="Windows Python 2.7 inserts 'L' after numbers in repr",
-)
 def test():
     assert str(
         ak.Array(
