@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import os
 
 import pytest  # noqa: F401
@@ -20,7 +18,7 @@ def test_1(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:col:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:col:x[0]"}
     assert array.tolist() == data
 
 
@@ -34,7 +32,7 @@ def test_2(one, two, three, tmp_path):
     array.layout.field("x").array
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:col:x.y[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:col:x.y[0]"}
     assert array.tolist() == data
 
 
@@ -52,9 +50,9 @@ def test_3(one, two, three, tmp_path):
     array.layout.field("x").array
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array.field("z").array
-    assert set(array.caches[0].keys()) == set(["tmp:col:x.z[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:col:x.z[0]"}
     array.layout.field("x").array.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:col:x.z[0]", "tmp:col:x.y[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:col:x.z[0]", "tmp:col:x.y[0]"}
     assert array.tolist() == data
 
 
@@ -66,7 +64,7 @@ def test_4(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:lst:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:lst:x[0]"}
     assert array.tolist() == data
 
 
@@ -80,7 +78,7 @@ def test_5(one, two, three, tmp_path):
     array.layout.field("x").array
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:lst:x.y[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:lst:x.y[0]"}
     assert array.tolist() == data
 
 
@@ -98,18 +96,18 @@ def test_6(one, two, three, tmp_path):
     array.layout.field("x").array
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array.field("z").array
-    assert set(array.caches[0].keys()) == set(["tmp:col:x.z[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:col:x.z[0]"}
     array.layout.field("x").array.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:col:x.z[0]", "tmp:lst:x.y[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:col:x.z[0]", "tmp:lst:x.y[0]"}
     assert array.tolist() == data
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:lst:x.y[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:lst:x.y[0]"}
     array.layout.field("x").array.field("z").array
-    assert set(array.caches[0].keys()) == set(["tmp:lst:x.y[0]", "tmp:col:x.z[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:lst:x.y[0]", "tmp:col:x.z[0]"}
     assert array.tolist() == data
 
 
@@ -125,13 +123,14 @@ def test_7(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y:x[0]"}
     assert np.asarray(array.layout.field("x").array.offsets).tolist() == [0, 0, 1, 4]
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y:x[0]"}
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.y:x[0]", "tmp:col:x.list.item.y[0]"]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y:x[0]",
+        "tmp:col:x.list.item.y[0]",
+    }
     assert array.tolist() == data
 
 
@@ -147,40 +146,38 @@ def test_8(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y:x[0]"}
     assert np.asarray(array.layout.field("x").array.offsets).tolist() == [0, 0, 1, 4]
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y:x[0]"}
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.y:x[0]", "tmp:col:x.list.item.y[0]"]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y:x[0]",
+        "tmp:col:x.list.item.y[0]",
+    }
     array.layout.field("x").array.content.field("z").array
-    assert set(array.caches[0].keys()) == set(
-        [
-            "tmp:off:x.list.item.y:x[0]",
-            "tmp:col:x.list.item.y[0]",
-            "tmp:col:x.list.item.z[0]",
-        ]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y:x[0]",
+        "tmp:col:x.list.item.y[0]",
+        "tmp:col:x.list.item.z[0]",
+    }
     assert array.tolist() == data
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y:x[0]"}
     assert np.asarray(array.layout.field("x").array.offsets).tolist() == [0, 0, 1, 4]
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y:x[0]"}
     array.layout.field("x").array.content.field("z").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.y:x[0]", "tmp:col:x.list.item.z[0]"]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y:x[0]",
+        "tmp:col:x.list.item.z[0]",
+    }
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(
-        [
-            "tmp:off:x.list.item.y:x[0]",
-            "tmp:col:x.list.item.z[0]",
-            "tmp:col:x.list.item.y[0]",
-        ]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y:x[0]",
+        "tmp:col:x.list.item.z[0]",
+        "tmp:col:x.list.item.y[0]",
+    }
     assert array.tolist() == data
 
 
@@ -196,15 +193,16 @@ def test_9(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.q:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.q:x[0]"}
     assert np.asarray(array.layout.field("x").array.offsets).tolist() == [0, 0, 1, 4]
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.q:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.q:x[0]"}
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.q:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.q:x[0]"}
     array.layout.field("x").array.content.field("y").array.field("q").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.y.q:x[0]", "tmp:col:x.list.item.y.q[0]"]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y.q:x[0]",
+        "tmp:col:x.list.item.y.q[0]",
+    }
     assert array.tolist() == data
 
 
@@ -226,44 +224,42 @@ def test_10(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.q:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.q:x[0]"}
     assert np.asarray(array.layout.field("x").array.offsets).tolist() == [0, 0, 1, 4]
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.q:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.q:x[0]"}
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.q:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.q:x[0]"}
     array.layout.field("x").array.content.field("y").array.field("q").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.y.q:x[0]", "tmp:col:x.list.item.y.q[0]"]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y.q:x[0]",
+        "tmp:col:x.list.item.y.q[0]",
+    }
     array.layout.field("x").array.content.field("z").array
-    assert set(array.caches[0].keys()) == set(
-        [
-            "tmp:off:x.list.item.y.q:x[0]",
-            "tmp:col:x.list.item.y.q[0]",
-            "tmp:col:x.list.item.z[0]",
-        ]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y.q:x[0]",
+        "tmp:col:x.list.item.y.q[0]",
+        "tmp:col:x.list.item.z[0]",
+    }
     assert array.tolist() == data
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.q:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.q:x[0]"}
     assert np.asarray(array.layout.field("x").array.offsets).tolist() == [0, 0, 1, 4]
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.q:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.q:x[0]"}
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.q:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.q:x[0]"}
     array.layout.field("x").array.content.field("z").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.y.q:x[0]", "tmp:col:x.list.item.z[0]"]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y.q:x[0]",
+        "tmp:col:x.list.item.z[0]",
+    }
     array.layout.field("x").array.content.field("y").array.field("q").array
-    assert set(array.caches[0].keys()) == set(
-        [
-            "tmp:off:x.list.item.y.q:x[0]",
-            "tmp:col:x.list.item.y.q[0]",
-            "tmp:col:x.list.item.z[0]",
-        ]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y.q:x[0]",
+        "tmp:col:x.list.item.y.q[0]",
+        "tmp:col:x.list.item.z[0]",
+    }
     assert array.tolist() == data
 
 
@@ -285,44 +281,28 @@ def test_11(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.z:x[0]"])
+    assert len(set(array.caches[0].keys())) == 1
     assert np.asarray(array.layout.field("x").array.offsets).tolist() == [0, 0, 1, 4]
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.z:x[0]"])
+    assert len(set(array.caches[0].keys())) == 1
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.z:x[0]"])
+    assert len(set(array.caches[0].keys())) == 1
     array.layout.field("x").array.content.field("y").array.field("q").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.z:x[0]", "tmp:col:x.list.item.y.q[0]"]
-    )
+    assert len(set(array.caches[0].keys())) == 2
     array.layout.field("x").array.content.field("z").array
-    assert set(array.caches[0].keys()) == set(
-        [
-            "tmp:off:x.list.item.z:x[0]",
-            "tmp:col:x.list.item.y.q[0]",
-            "tmp:col:x.list.item.z[0]",
-        ]
-    )
+    assert len(set(array.caches[0].keys())) == 3
     assert array.tolist() == data
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.z:x[0]"])
+    assert len(set(array.caches[0].keys())) == 1
     assert np.asarray(array.layout.field("x").array.offsets).tolist() == [0, 0, 1, 4]
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.z:x[0]"])
+    assert len(set(array.caches[0].keys())) == 1
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.z:x[0]"])
+    assert len(set(array.caches[0].keys())) == 1
     array.layout.field("x").array.content.field("z").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.z:x[0]", "tmp:col:x.list.item.z[0]"]
-    )
+    assert len(set(array.caches[0].keys())) == 2
     array.layout.field("x").array.content.field("y").array.field("q").array
-    assert set(array.caches[0].keys()) == set(
-        [
-            "tmp:off:x.list.item.z:x[0]",
-            "tmp:col:x.list.item.y.q[0]",
-            "tmp:col:x.list.item.z[0]",
-        ]
-    )
+    assert len(set(array.caches[0].keys())) == 3
     assert array.tolist() == data
 
 
@@ -340,7 +320,7 @@ def test_12(one, two, three, tmp_path):
     array.layout.field("x").array
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:lst:x.y[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:lst:x.y[0]"}
     assert array.tolist() == data
 
 
@@ -358,18 +338,18 @@ def test_13(one, two, three, tmp_path):
     array.layout.field("x").array
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array.field("z").array
-    assert set(array.caches[0].keys()) == set(["tmp:col:x.z[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:col:x.z[0]"}
     array.layout.field("x").array.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:col:x.z[0]", "tmp:lst:x.y[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:col:x.z[0]", "tmp:lst:x.y[0]"}
     assert array.tolist() == data
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array.field("y").array
-    assert set(array.caches[0].keys()) == set(["tmp:lst:x.y[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:lst:x.y[0]"}
     array.layout.field("x").array.field("z").array
-    assert set(array.caches[0].keys()) == set(["tmp:lst:x.y[0]", "tmp:col:x.z[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:lst:x.y[0]", "tmp:col:x.z[0]"}
     assert array.tolist() == data
 
 
@@ -385,36 +365,34 @@ def test_14(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.list.item:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.list.item:x[0]"}
     array.layout.field("x").array.content.field("z").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.y.list.item:x[0]", "tmp:col:x.list.item.z[0]"]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y.list.item:x[0]",
+        "tmp:col:x.list.item.z[0]",
+    }
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(
-        [
-            "tmp:off:x.list.item.y.list.item:x[0]",
-            "tmp:col:x.list.item.z[0]",
-            "tmp:lst:x.list.item.y[0]",
-        ]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y.list.item:x[0]",
+        "tmp:col:x.list.item.z[0]",
+        "tmp:lst:x.list.item.y[0]",
+    }
     assert array.tolist() == data
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.field("x").array
-    assert set(array.caches[0].keys()) == set(["tmp:off:x.list.item.y.list.item:x[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:x.list.item.y.list.item:x[0]"}
     array.layout.field("x").array.content.field("y").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:x.list.item.y.list.item:x[0]", "tmp:lst:x.list.item.y[0]"]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y.list.item:x[0]",
+        "tmp:lst:x.list.item.y[0]",
+    }
     array.layout.field("x").array.content.field("z").array
-    assert set(array.caches[0].keys()) == set(
-        [
-            "tmp:off:x.list.item.y.list.item:x[0]",
-            "tmp:lst:x.list.item.y[0]",
-            "tmp:col:x.list.item.z[0]",
-        ]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:x.list.item.y.list.item:x[0]",
+        "tmp:lst:x.list.item.y[0]",
+        "tmp:col:x.list.item.z[0]",
+    }
     assert array.tolist() == data
 
 
@@ -426,7 +404,7 @@ def test_15(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     array.layout.array
-    assert set(array.caches[0].keys()) == set(["tmp:col:[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:col:[0]"}
     assert array.tolist() == data
 
 
@@ -438,7 +416,7 @@ def test_16(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     assert np.asarray(array.layout.array.offsets).tolist() == [0, 2, 2, 3]
-    assert set(array.caches[0].keys()) == set(["tmp:lst:[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:lst:[0]"}
     assert array.tolist() == data
 
 
@@ -450,9 +428,10 @@ def test_17(one, two, three, tmp_path):
     array = ak.from_parquet(filename, lazy=True, lazy_cache_key="tmp")
     assert set(array.caches[0].keys()) == set()
     assert np.asarray(array.layout.array.offsets).tolist() == [0, 2, 2, 3]
-    assert set(array.caches[0].keys()) == set(["tmp:off:.list.item.x:[0]"])
+    assert set(array.caches[0].keys()) == {"tmp:off:.list.item.x:[0]"}
     array.layout.array.content.field("x").array
-    assert set(array.caches[0].keys()) == set(
-        ["tmp:off:.list.item.x:[0]", "tmp:col:.list.item.x[0]"]
-    )
+    assert set(array.caches[0].keys()) == {
+        "tmp:off:.list.item.x:[0]",
+        "tmp:col:.list.item.x[0]",
+    }
     assert array.tolist() == data
