@@ -1,7 +1,5 @@
 # BSD 3-Clause License; see https://github.com/scikit-hep/awkward-1.0/blob/main/LICENSE
 
-from __future__ import absolute_import
-
 import pytest  # noqa: F401
 import numpy as np  # noqa: F401
 import awkward as ak  # noqa: F401
@@ -9,7 +7,7 @@ import awkward as ak  # noqa: F401
 
 def test():
     @ak.mixin_class(ak.behavior)
-    class Blah(object):
+    class Blah:
         @property
         def blah(self):
             return self["x"]
